Helpers class

Constructors

Helpers()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isBlock(dynamic node) → bool
Checks if the node is an instance of Block
isHeader(dynamic node) → bool
Checks if the node is a Header
Checks if the node is an instance of Hyperlink
isInline(dynamic node) → bool
Checks if the node is an instance of Inline
isParagraph(dynamic node) → bool
Checks if the node is an instance of Paragraph
isText(dynamic node) → bool
Checks if the node is an instance of Text
isTopLevelBlock(dynamic node) → bool
Checks if the node is an instance of TopLevelBlocks