MARKS class

Map of all Contentful marks

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](dynamic index) → dynamic

Static Properties

defaultMarkRenderers ↔ RenderMark
getter/setter pair
items → List<MARKS>
no setter

Static Methods

fromKey(String key) → dynamic
fromValue(String value) → dynamic
getMarksTextStyles(List<Mark> marks, Map<dynamic, TextStyle> renderMark) → TextStyle
renderMarks(Map<dynamic, TextStyle>? optionRenderMarks) → Map<dynamic, TextStyle>

Constants

BOLD → const MARKS
ITALIC → const MARKS
UNDERLINE → const MARKS