Document class

Inheritance

Constructors

Document({required List content, required String nodeType, required Map data})

Properties

content → List
final
data ↔ Map?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
nodeType → BLOCKS
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic richTextJson) → Document?